@@ -139,6 +139,8 @@ def _parse_type(tokens):
         return BarePrimitive(TypeKind.Bool)
     elif token.token == Token.TSTRING:
         return BarePrimitive(TypeKind.String)
+    elif token.token == Token.TVOID:
+        return BarePrimitive(TypeKind.Void)
     elif token.token == Token.TOPTIONAL:
         token = tokens.__next__()
         if token.token != Token.TLANGLE:
